aboutsummaryrefslogtreecommitdiffstats
path: root/src/render.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/render.h')
-rw-r--r--src/render.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/render.h b/src/render.h
index 93ca32a..27da080 100644
--- a/src/render.h
+++ b/src/render.h
@@ -7,7 +7,12 @@ void term_init(void);
void term_restore(void);
void render_frame(GB *gb);
void render_force_full(void); // force a complete repaint next frame
// Poll keyboard, update gb->buttons. Returns false if quit requested.
bool input_poll(GB *gb);
+// Optional external control channel: a named pipe (FIFO) that accepts button
+// commands (see README). Safe to call once at startup.
+void input_open_fifo(const char *path);
+void input_close_fifo(void);
+
#endif
@@ -7,7 +7,12 @@ void term_init(void);
void render_frame(GB *gb);
void render_force_full(void); // force a complete repaint next frame
-// Poll keyboard, update gb->buttons. Returns false if quit requested.
+// Poll keyboard + control FIFO, update gb->buttons. False if quit requested.
bool input_poll(GB *gb);